/*
 * preset-browser.h
 * Copyright 2014 John Lindgren
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions, and the following disclaimer in the documentation
 *    provided with the distribution.
 *
 * This software is provided "as is" and without any warranty, express or
 * implied. In no event shall the authors be liable for any damages arising from
 * the use of this software.
 */

#ifndef AUDGUI_PRESET_BROWSER_H
#define AUDGUI_PRESET_BROWSER_H

#include <libaudcore/equalizer.h>

void eq_preset_load_file ();
void eq_preset_load_eqf ();
void eq_preset_save_file (const EqualizerPreset & preset);
void eq_preset_save_eqf (const EqualizerPreset & preset);

#endif // AUDGUI_PRESET_BROWSER_H
